---
name: "\U0001F680 Feature request"
about: Suggest an idea for this project
labels: enhancement

---

<!--
Thank you for contributing ideas to smol!

Please fill in as much of the template below as you're able.
-->

**Is your feature request related to a problem? Please describe.**
Please describe the problem you are trying to solve.

**Describe the solution you'd like**
Please describe the desired behavior.

**Describe alternatives you've considered**
Please describe alternative solutions or features you have considered.
